local jfm={
 [0]={
  ["align"]="middle",
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["left"]=0,
  ["width"]=1,
 },
 {
  ["align"]="right",
  ["chars"]={ "（", "〔", "［", "｛", "〈", "《", "「", "『", "【", "｟", "〘", "〖", "«", "〝", "‘", "“" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [9]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [10]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [11]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [12]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [13]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [15]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [16]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [27]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=0.5,
 },
 {
  ["align"]="left",
  ["chars"]={ "）", "〕", "］", "｝", "〉", "》", "」", "』", "】", "｠", "〙", "〗", "»", "〟", "’", "”" },
  ["depth"]=0.5,
  ["end_adjust"]={ 0.5, 0 },
  ["glue"]={
   [0]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [9]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [10]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [11]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [12]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [13]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [15]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [16]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [27]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [300]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [301]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [302]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
  },
  ["height"]=0.5,
  ["width"]=0.5,
 },
 [4]={
  ["align"]="middle",
  ["chars"]={ "！", "？", "‼", "⁇", "⁈", "⁉" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [9]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [10]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [11]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [12]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [13]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [15]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [16]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=1,
 },
 [5]={
  ["align"]="middle",
  ["chars"]={ "・", "：", "；" },
  ["depth"]=0.5,
  ["end_adjust"]={ 0.25, 0 },
  ["glue"]={
   [0]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   {
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   {
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [4]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [5]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0.5,
   },
   [6]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [7]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [8]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [9]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [10]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [11]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [12]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [13]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [14]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [15]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [16]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [27]={
    0.25,
    0.25,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -1 },
    ["ratio"]=0,
   },
   [300]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [301]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
   [302]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0,
   },
  },
  ["height"]=0.5,
  ["width"]=0.5,
 },
 [6]={
  ["align"]="left",
  ["chars"]={ "。", "．" },
  ["depth"]=0.5,
  ["end_adjust"]={ 0.5, 0 },
  ["glue"]={
   [0]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   {
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
   [5]={
    0.75,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0.33333333,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [9]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
   [10]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
   [11]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
   [12]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [13]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [14]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [15]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [16]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [27]={
    0.5,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
    ["ratio"]=0,
   },
   [300]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
   [301]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
   [302]={
    0.5,
    0,
    0,
    ["kanjiskip_natural"]=1,
    ["ratio"]=0,
   },
  },
  ["height"]=0.5,
  ["width"]=0.5,
 },
 [7]={
  ["align"]="left",
  ["chars"]={ "、", "，" },
  ["depth"]=0.5,
  ["end_adjust"]={ 0.5, 0 },
  ["glue"]={
   [0]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [5]={
    0.75,
    0,
    0.75,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=0.33333333,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [9]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [10]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [11]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [12]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [13]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [14]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [15]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [16]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [27]={
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=0,
   },
   [300]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [301]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
   [302]={
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=0,
   },
  },
  ["height"]=0.5,
  ["width"]=0.5,
 },
 [8]={
  ["align"]="middle",
  ["chars"]={ "—", "…", "‥", "〳", "〴", "〵" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={ 0, 0, 0 },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=1,
 },
 [9]={
  ["align"]="middle",
  ["chars"]={ "ヽ", "ヾ", "ゝ", "ゞ", "々", "〻" },
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [10]={
  ["align"]="middle",
  ["chars"]={ "ー" },
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [11]={
  ["align"]="middle",
  ["chars"]={ "ぁ", "ぃ", "ぅ", "ぇ", "ぉ", "ァ", "ィ", "ゥ", "ェ", "ォ", "っ", "ゃ", "ゅ", "ょ", "ゎ", "ゕ", "ゖ", "ッ", "ャ", "ュ", "ョ", "ヮ", "ヵ", "ヶ", "ㇰ", "ㇱ", "ㇲ", "ㇳ", "ㇴ", "ㇵ", "ㇶ", "ㇷ", "ㇸ", "ㇹ", "ㇺ", "ㇻ", "ㇼ", "ㇽ", "ㇾ", "ㇿ", "ㇷ゚" },
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [12]={
  ["align"]="middle",
  ["chars"]={ "￥", "＄", "￡", "＃", "€", "№" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   {
    0.5,
    0,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [13]={
  ["align"]="middle",
  ["chars"]={ "°", "′", "″", "℃", "￠", "％", "‰", "㏋", "ℓ", "㌃", "㌍", "㌔", "㌘", "㌢", "㌣", "㌦", "㌧", "㌫", "㌶", "㌻", "㍉", "㍊", "㍍", "㍑", "㍗", "㎎", "㎏", "㎜", "㎝", "㎞", "㎡", "㏄" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [14]={
  ["align"]="middle",
  ["chars"]={ "　" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   {
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [9]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [10]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [11]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [12]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [13]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [15]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [16]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=1,
 },
 [15]={
  ["align"]="middle",
  ["chars"]={ "あ", "い", "う", "え", "お", "か", "が", "き", "ぎ", "く", "ぐ", "け", "げ", "こ", "ご", "さ", "ざ", "し", "じ", "す", "ず", "せ", "ぜ", "そ", "ぞ", "た", "だ", "ち", "ぢ", "つ", "づ", "て", "で", "と", "ど", "な", "に", "ぬ", "ね", "の", "は", "ば", "ぱ", "ひ", "び", "ぴ", "ふ", "ぶ", "ぷ", "へ", "べ", "ぺ", "ほ", "ぼ", "ぽ", "ま", "み", "む", "め", "も", "や", "ゆ", "よ", "ら", "り", "る", "れ", "ろ", "わ", "ゐ", "ゑ", "を", "ん", "ゔ", "か゚", "き゚", "く゚", "け゚", "こ゚" },
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [16]={
  ["align"]="middle",
  ["chars"]={ "ア", "イ", "ウ", "エ", "オ", "カ", "ガ", "キ", "ギ", "ク", "グ", "ケ", "ゲ", "コ", "ゴ", "サ", "ザ", "シ", "ジ", "ス", "ズ", "セ", "ゼ", "ソ", "ゾ", "タ", "ダ", "チ", "ヂ", "ツ", "ヅ", "テ", "デ", "ト", "ド", "ナ", "ニ", "ヌ", "ネ", "ノ", "ハ", "バ", "パ", "ヒ", "ビ", "ピ", "フ", "ブ", "プ", "ヘ", "ベ", "ペ", "ホ", "ボ", "ポ", "マ", "ミ", "ム", "メ", "モ", "ヤ", "ユ", "ヨ", "ラ", "リ", "ル", "レ", "ロ", "ワ", "ヰ", "ヱ", "ヲ", "ン", "ヴ", "ヷ", "ヸ", "ヹ", "ヺ", "カ゚", "キ゚", "ク゚", "ケ゚", "コ゚", "セ゚", "ツ゚", "ト゚" },
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [27]={
  ["chars"]={ "alchar" },
  ["depth"]=0.5,
  ["glue"]={
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   [12]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, 0 },
   },
   [13]={
    0,
    0.25,
    0,
    ["priority"]={ 0, 0 },
   },
   [14]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
 },
 [90]={
  ["chars"]={ "parbdd", "boxbdd" },
  ["depth"]=0.5,
  ["glue"]={
   { 0, 0, 0 },
  },
  ["height"]=0.5,
 },
 [300]={
  ["align"]="middle",
  ["chars"]={ "‐" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [9]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [10]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [11]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [12]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [13]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [15]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [16]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=0.25,
 },
 [301]={
  ["align"]="middle",
  ["chars"]={ "゠", "–" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [9]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [10]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [11]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [12]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [13]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [15]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [16]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=0.5,
 },
 [302]={
  ["align"]="middle",
  ["chars"]={ "〜" },
  ["depth"]=0.5,
  ["glue"]={
   [0]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   {
    0.5,
    0.25,
    0.5,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, -2 },
    ["ratio"]=1,
   },
   {
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [4]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [5]={
    0.25,
    0,
    0.25,
    ["kanjiskip_natural"]=1,
    ["priority"]={ 0, -1 },
    ["ratio"]=1,
   },
   [6]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [7]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [8]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [9]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [10]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [11]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [12]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [13]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [14]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [15]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [16]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [27]={
    0,
    0.25,
    0,
    ["kanjiskip_natural"]=1,
    ["priority"]={ -1, 0 },
   },
   [300]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [301]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
   [302]={
    0,
    0,
    0,
    ["kanjiskip_natural"]=1,
   },
  },
  ["height"]=0.5,
  ["width"]=1,
 },
 ["dir"]="tate",
 ["kanjiskip"]={ 0, 0.25, 0 },
 ["version"]=3,
 ["xkanjiskip"]={ 0.25, 0.25, 0.125 },
 ["zh"]=1.0,
 ["zw"]=1.0,
}
local function add_space(before,after,glueorkern,space,ratio)
	if jfm[before][glueorkern] == nil then jfm[before][glueorkern] = {} end
	if jfm[before][glueorkern][after] == nil then jfm[before][glueorkern][after] = {0} end
	local origratio = jfm[before][glueorkern][after].ratio
	if origratio == nil then origratio = 0.5 end
	jfm[before][glueorkern][after].ratio = (jfm[before][glueorkern][after][1] * origratio + space * ratio) /  (jfm[before][glueorkern][after][1] + ratio)
	jfm[before][glueorkern][after][1] = jfm[before][glueorkern][after][1] + space
end

if jlreq ~= nil then
	if type(jlreq.open_bracket_pos) == "string" then
		local r = jlreq.open_bracket_pos:find("_")
		local danraku = jlreq.open_bracket_pos:sub(1,r - 1)
		local orikaeshi = jlreq.open_bracket_pos:sub(r + 1)

		-- 折り返し行頭の開き括弧を二分下げる……つもり
		if orikaeshi == "nibu" then
			-- widthを二分増やし，その代わりJFMグルーを二分減らす
			jfm[1].width = jfm[1].width + 0.5
			for k,v in pairs(jfm) do
				if type(k) == "number" then
					add_space(k,1,"glue",-0.5,1)
				end
			end
		end

		-- 段落行頭の下げ
		if danraku == "zenkakunibu" then
			add_space(90,1,"glue",0.5,1)
		elseif danraku == "nibu" then
			add_space(90,1,"glue",-0.5,1)
		end
	end

	-- ぶら下げ組を有効にする．
	if jlreq.burasage == true then
		for _,class in ipairs({6,7}) do
			table.insert(jfm[class].end_adjust,-0.5)
		end
	end
end
luatexja.jfont.define_jfm(jfm)
